#ifndef __KONFIGURACJA_H
#define __KONFIGURACJA_H

// ----------------------------------------------------------------------------------
// ---  Ustawienia konfiguracyjne
// ----------------------------------------------------------------------------------
  
  //----- KONFIGURACJA SERW --------
  #define SERWO_A_ZAKRES 600  // [us] - zakres ruchu serwa min-do-max (1 stopien obrotu ~ 11.1us) 600us ~ 54 stopnie
  #define SERWO_A_TRYM 70     // [us] - doregulowanie pozycji "neutralnej"
  #define SERWO_A_REWERS 1    //      - odwrocenie kierunku obrotu serwa (kiedy "w prawo" jest "w lewo") 1 - rewers, 0 - normalnie

  //----- KONFIGURACJA SILNIKA -----
  #define MOTOR_PWM_MAX 1023        // - maksymalne wypelnienie PWM dla silnika (max = 1023)
  #define MOTOR_PWM_MIN 800         // - minimalne wypelnienie PWM dla silnika
  #define MOTOR_LUZ 40              // - strefa braku reakcji dla drazka gazu

  //----- MONITOROWANIE BATERII ----
  #define BAT_MON_EN      0         // - monitor baterii 1 - aktywny, 0 - nieaktywny
  #define BAT_MON_R7_560K 0         // - Rezystor dzielnika R7 = 560k
  #define BAT_MON_R7_1M   1         // - Rezystor dzielnika R7 = 1M
  #define BAT_VALARM_X10V 72        // - napięcie zadzialania zabezpieczenia x10, 72 = 7.2V
                                    //   ze wzgledu na duze wartosci dzielnikow w module pomiar
                                    //   nie jest precyzyjny
  #define DEBUG_EN 0                // - musi byc wlaczony aby dzialaly komunikaty diagnostyczne
  // 1 - aktywny
  // 0 - nieaktywny
  #define KALIBRACJA_ADC_EN 0       // - Kalibracja dzielnika napięciowego ADC
  // 1 - aktywna                         wymaga aktywacji komunikatow diagnostycznych
  // 0 - nieaktywna                      (DEBUG_EN 1). Po zakonczeniu kalibracji nalezy zaladowac
  //                                     program z przelacznikami DEBUG_EN 0 oraz KALIBRACJA_ADC_EN 0
  #define WSP_KALIBRACJI  1.0432    // - Wyliczony współczynnik korekty pomiarow ADC. 
                                    //   = [ Wartosc rzeczywista / Wartosc zmierzona ]
// ----------------------------------------------------------------------------------
// ---  Zmiany ponizej tej lini niewskazane
// ----------------------------------------------------------------------------------

  //------ KOMUNIKACJA "DEBUGERA" ----
  #define DEBUG_WIFI_EN   0   // - komunikaty dotyczące sieci WiFi
  #define DEBUG_UDP_EN    0   // - komunikaty dotyczące komunikacji UDP
  #define DEBUG_SERWO_EN  0   // - komunikaty dotyczące poruszania serwem
  #define DEBUG_MOTOR_EN  0   // - komunikaty dotyczące sterowania silnikiem
  #define DEBUG_VMON_EN   0   // - komunikaty dotyczące monitora napięcia zasilającego
  
  //----- ESP8266 ------------------
  #define ESP8266_PWM_MAX 1023            // - maksymalne wypelnienie PWM dla biblioteki Arduino
  #define ESP8266_PWM_CZESTOTLIWOSC 20000 // - czestotliwosc odswiezania sygnalu PWM [Hz]
  
  //----- MONITOROWANIE BATERII ----
  #if BAT_MON_R7_560K
    #define BAT_MON_DIV 88
  #endif
  #if BAT_MON_R7_1M
    #define BAT_MON_DIV 132
  #endif
  #define BAT_VALARM_X10 (BAT_VALARM_X10V*10230)/(BAT_MON_DIV * WSP_KALIBRACJI)
  
  //----- KONFIGURACJA SERW --------
  #define SERWO_MAX 1000      // [us] - maksymalna roznica sygnalu sterujacego = abs(1000us - 2000us), srodek = 1500us
  #define SERWO_NEUTRUM 1500  // [us]

  //----- KONFIGURACJA SILNIKA -----
  #define MOTOR_ZERO 1500                                 // - neutralne położenie drazka "gazu"
  #define MOTOR_PWM_WE_MAX  500                           // - maksymalna wartosc (+/-) "z drazka"
  #define MOTOR_PWM_WE_DOST (MOTOR_PWM_WE_MAX-MOTOR_LUZ)  // - dostepny zakres uzyteczny "z drazka"
  #define MOTOR_PWM_MAX_MIN (MOTOR_PWM_MAX-MOTOR_PWM_MIN) // - dostepny zakres uzyteczny PWM dla danego silnika
    
  //------ KONFIGURACJA PINOW ------
  #define WYBUF_ENN_PIN     5  // D1
  #define LEDC_CTRL_PIN     4  // D2
  #define LEDZ_CTRL_PIN     0  // D3
  #define TRYM_KIER_PIN     2  // D4
  #define SILNIK_CTRL_A_PIN 14 // D5
  #define SILNIK_CTRL_B_PIN 16 // D0
  #define SBUF_EN_PIN       12 // D6
  #define SERWO_A_PIN       15 // D8
  #define SERWO_B_PIN       13 // D7
  #define ADC_PIN           0  // A0
  
  //----- KONFIGURACJA WIFI --------
  #define WIFI_AP_SSID "ESP8266 RC"           // Nazwa sieci WiFi (SSID)
  #define WIFI_AP_PASS ""                     // haslo
  #define WIFI_AP_CHANNEL 7                   // kanal 1-13
  #define WIFI_AP_HIDE false                  // siec ukryta = false
  #define WIFI_AP_MAXC 2                      // maxymalna liczba polaczen 0 - 8 (nie dziala !)
  #define UDP_PORT 12000                      // port komunikacyjny nr 12000
  
  //----- KONFIGURACJA RS232 -------
  #define RS232_PREDKOSC 115200
  
#endif // __KONFIGURACJA_H
